@ECHO OFF
REM
REM DESCRIPTION:
REM This script is used to create TMTP database and tables manually for DB2
REM
REM USAGE:
REM crtdb_db2 db2_version dbname dbuser dbpasswd country_code
REM

REM Get the arguments
set DB2VERSION=%1%
set DBNAME=%2%
set DBUSER=%3%
set DBPASSWD=%4%
set COUNTRY_CODE=%5%
set CREATE_DB=%6%
set WAS_USER=%7%

REM Get current directory
set THIS_CMD_PATH=%~f0
set THIS_CMD_DIR=%THIS_CMD_PATH:\crtdb_db2.bat=%
set CMD_DIR_PARENT=%THIS_CMD_DIR:\utilities=%

REM Verify java is available on the system
set CLP=-Djava.class.path="%CMD_DIR_PARENT%\scripts\install.jar" com.ibm.tivoli.transperf.util.DisplayMessage

if "%JAVA_HOME%"=="" (
set JAVA_BIN=%CMD_DIR_PARENT%\java\jre\bin\java.exe
REM if not exist "%JAVA_BIN%" set JAVA_BIN=
)

if NOT "%JAVA_HOME%"=="" (
set JAVA_BIN=%JAVA_HOME%\bin\java.exe
)


REM test if the variables contain something
if "%DB2VERSION%"=="" goto PRINT_USAGE
if NOT "%DB2VERSION%"=="8.1" (
if NOT "%DB2VERSION%"=="8.2" (
if NOT "%DB2VERSION%"=="9.1" (
if NOT "%DB2VERSION%"=="9.2" (
goto PRINT_USAGE
)
)
)
)
if NOT "%DB2VERSION%"=="9.2" (
if NOT "%DB2VERSION%"=="9.1" (
if NOT "%DB2VERSION%"=="8.2" (
if NOT "%DB2VERSION%"=="8.1" (
goto PRINT_USAGE
)
)
)
)
if "%DBNAME%"=="" goto PRINT_USAGE
if "%DBUSER%"=="" goto PRINT_USAGE
if "%DBPASSWD%"=="" goto PRINT_USAGE
if "%COUNTRY_CODE%"=="" goto PRINT_USAGE
if "%CREATE_DB%"=="" goto PRINT_USAGE
if NOT "%CREATE_DB%"=="Y" (
if NOT "%CREATE_DB%"=="N" (
goto PRINT_USAGE
)
)
if NOT "%CREATE_DB%"=="N" (
if NOT "%CREATE_DB%"=="Y" (
goto PRINT_USAGE
)
)
if "%WAS_USER%"=="" goto PRINT_USAGE

if "%CREATE_DB%"=="Y" (
  "%JAVA_BIN%" %CLP% crtdbCreating

db2 create database %DBNAME% USING CODESET UTF-8 TERRITORY %COUNTRY_CODE%
db2 connect to %DBNAME% user %DBUSER% using %DBPASSWD%
db2 create bufferpool buffpool32k size 100 pagesize 32k
db2 update db cfg using LOCKLIST 150
db2 update db cfg using MAXLOCKS 35
)

if "%CREATE_DB%"=="N" (
db2 connect to %DBNAME% user %DBUSER% using %DBPASSWD%
)

REM 8.1 and 8.2 run same scripts for now
if "%DB2VERSION%"=="8.1" goto DB281
db2 -tf "%THIS_CMD_DIR%\DB2UDB_V81\db2_createTableSpace.ddl"
db2 -tf "%THIS_CMD_DIR%\DB2UDB_V81\Table.ddl"
goto MORESQL

:DB281
db2 -tf "%THIS_CMD_DIR%\DB2UDB_V81\db2_createTableSpace.ddl"
db2 -tf "%THIS_CMD_DIR%\DB2UDB_V81\Table.ddl"

:MORESQL
db2 -tf "%THIS_CMD_DIR%\DB2UDB_V81\CreateCore.sql"
db2 -tf "%THIS_CMD_DIR%\DB2UDB_V81\PopCore.sql"
db2 -td@ -f "%THIS_CMD_DIR%\DB2UDB_V81\dm_db2_2.ddl"
db2 -tf "%THIS_CMD_DIR%\DB2UDB_V81\dmPrePopulate.sql"

db2 insert into usersettings (USERNAME, TIMEZONEID, DST, BBREFRESHRATE) values ('%WAS_USER%', 'GMT', 1, 5)
db2 insert into usersettings_roles values(1, '%WAS_USER%')
db2 disconnect %DBNAME%

if "%CREATE_DB%"=="Y" (
db2 update database configuration for %DBNAME% using APPLHEAPSZ 512
db2 update database configuration for %DBNAME% using LOGFILSIZ 8000
db2 update database configuration for %DBNAME% using LOGPRIMARY 3
db2 update database configuration for %DBNAME% using LOGSECOND 2
)

goto END

:PRINT_USAGE
if "%JAVA_BIN%"=="" (
echo Usage: crtdb_db2 db2_version dbname dbuser dbpasswd country_code create_db was_user
echo   where
echo   db2_version can be 9.1, 8.1 or 8.2
echo   dbname is TMTP database name, e.g. tmtp
echo   dbuser is db2 admin user
echo   dbpasswd is the db2admin password
echo   country_code is locale name as understood by DB2
echo   create_db is Y or N, Y creates a new database
echo   was_user is the user WAS is running under
echo  e.g. crtdb_db2 8.1 tmtp db2admin db2passwd US Y Administrator
goto END1
)

if NOT "%JAVA_BIN%"=="" (
"%JAVA_BIN%" %CLP% crtdbUsage
goto END1
)

:END
if "%JAVA_BIN%"=="" echo Creating TMTP database and tables done.
if NOT "%JAVA_BIN%"=="" "%JAVA_BIN%" %CLP% crtdbDone

:END1